@@ -16,7 +16,6 @@
 #'
 #' @note The function also, Creates a csv file with the retrieved information.
 #'
-#' @examples Obj <- GetExpression("O14520")
 #'
 #' @export
 #'
@@ -39,7 +38,7 @@ GetExpression <- function(ProteinAccList , directorypath = NULL){
       #to see if Request == 200 or not
       Request <- tryCatch(
         {
-          GET(paste0(baseUrl , ProteinAcc,".xml") , timeout(10))
+          GET(paste0(baseUrl , ProteinAcc,".xml"))
         },error = function(cond)
         {
           message("Internet connection problem occurs and the function will return the original error")
@@ -53,7 +52,11 @@ GetExpression <- function(ProteinAccList , directorypath = NULL){
 
       RequestUrl <- paste0(baseUrl , ProteinName_url)
       RequestUrl <- URLencode(RequestUrl)
-      
+      if (length(Request) == 0)
+      {
+        message("Internet connection problem occurs")
+        return()
+      }
       if (Request$status_code == 200){
         # parse the information in DataFrame
         ProteinDataTable <- tryCatch(read.csv(RequestUrl, header = TRUE, sep = '\t'), error=function(e) NULL)
