@@ -39,7 +39,7 @@ GetPathology_Biotech<- function(ProteinAccList , directorypath = NULL){
     #to see if Request == 200 or not
     Request <- tryCatch(
       {
-        GET(paste0(baseUrl , ProteinAcc,".xml") , timeout(10))
+        GET(paste0(baseUrl , ProteinAcc,".xml"))
       },error = function(cond)
       {
         message("Internet connection problem occurs and the function will return the original error")
